# .

[![PyPI - Version](https://img.shields.io/pypi/v/-.svg)](https://pypi.org/project/-)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/-.svg)](https://pypi.org/project/-)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install -
```

## License

`-` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
